@@ -27,8 +27,8 @@ class ConfClass(object):
         for i in keys:
             if i[0] != "_":
                 r = repr(getattr(self, i))
-                r = r.replace("\n"," ")
-                wlen = 78-max(len(i),10)
+                r = " ".join(r.split())
+                wlen = 76-max(len(i),10)
                 if len(r) > wlen:
                     r = r[:wlen-3]+"..."
                 s += "%-10s = %s\n" % (i, r)
@@ -141,6 +141,8 @@ class CacheInstance(dict):
                 raise KeyError(item)
         return val
     def get(self, item, default=None):
+        # overloading this method is needed to force the dict to go through
+        # the timetable check
         try:
             return self[item]
         except KeyError:
@@ -148,16 +150,56 @@ class CacheInstance(dict):
     def __setitem__(self, item, v):
         self._timetable[item] = time.time()
         dict.__setitem__(self, item,v)
-    def __repr__(self):
+    def update(self, other):
+        dict.update(self, other)
+        self._timetable.update(other._timetable)
+    def iteritems(self):
         if self.timeout is None:
-            n = len(self)
-        else:
-            n = 0
-            t0 = time.time()
-            for t,v in self.itervalues():
-                if t0-t <= self.timeout:
-                    n += 1
-        return "%s: %i valid items. Timeout=%rs" % (self.name, n, self.timeout)
+            return dict.iteritems(self)
+        t0=time.time()
+        return ((k,v) for (k,v) in dict.iteritems(self) if t0-self._timetable[k] < self.timeout) 
+    def iterkeys(self):
+        if self.timeout is None:
+            return dict.iterkeys(self)
+        t0=time.time()
+        return (k for k in dict.iterkeys(self) if t0-self._timetable[k] < self.timeout)
+    def __iter__(self):
+        return self.iterkeys()
+    def itervalues(self):
+        if self.timeout is None:
+            return dict.itervalues(self)
+        t0=time.time()
+        return (v for (k,v) in dict.iteritems(self) if t0-self._timetable[k] < self.timeout)
+    def items(self):
+        if self.timeout is None:
+            return dict.items(self)
+        t0=time.time()
+        return [(k,v) for (k,v) in dict.iteritems(self) if t0-self._timetable[k] < self.timeout]
+    def keys(self):
+        if self.timeout is None:
+            return dict.keys(self)
+        t0=time.time()
+        return [k for k in dict.iterkeys(self) if t0-self._timetable[k] < self.timeout]
+    def values(self):
+        if self.timeout is None:
+            return dict.values(self)
+        t0=time.time()
+        return [v for (k,v) in dict.iteritems(self) if t0-self._timetable[k] < self.timeout]
+    def __len__(self):
+        if self.timeout is None:
+            return dict.__len__(self)
+        return len(self.keys())
+    def summary(self):
+        return "%s: %i valid items. Timeout=%rs" % (self.name, len(self), self.timeout)
+    def __repr__(self):
+        s = []
+        if self:
+            mk = max(len(k) for k in self.iterkeys())
+            fmt = "%%-%is %%s" % (mk+1)
+            for item in self.iteritems():
+                s.append(fmt % item)
+        return "\n".join(s)
+            
             
 
 
@@ -184,7 +226,7 @@ class NetCache:
         for c in self._caches_list:
             c.flush()
     def __repr__(self):
-        return "\n".join(repr(c) for c in self._caches_list)
+        return "\n".join(c.summary() for c in self._caches_list)
         
 
 class LogLevel(object):
@@ -222,7 +264,7 @@ noenum    : holds list of enum fields for which conversion to string should NOT
 AS_resolver: choose the AS resolver class to use
 extensions_paths: path or list of paths where extensions are to be looked for
 """
-    version = "2.0.0.7 beta"
+    version = "2.0.0.9 beta"
     session = ""
     interactive = False
     stealth = "not implemented"
@@ -251,6 +293,7 @@ extensions_paths: path or list of paths where extensions are to be looked for
     debug_match = 0
     wepkey = ""
     route = None # Filed by route.py
+    route6 = None # Filed by route6.py
     auto_fragment = 1
     debug_dissector = 0
     color_theme = themes.DefaultTheme()
@@ -270,9 +313,9 @@ extensions_paths: path or list of paths where extensions are to be looked for
     stats_dot11_protocols = []
     temp_files = []
     netcache = NetCache()
-    load_layers = ["l2", "inet", "dhcp", "dns", "dot11", "gprs", "hsrp", "ip6", "ir", "isakmp", "l2tp",
+    load_layers = ["l2", "inet", "dhcp", "dns", "dot11", "gprs", "hsrp", "inet6", "ir", "isakmp", "l2tp",
                    "mgcp", "mobileip", "netbios", "netflow", "ntp", "ppp", "radius", "rip", "rtp",
-                   "sebek", "skinny", "smb", "snmp", "tftp", "x509", "bluetooth" ]
+                   "sebek", "skinny", "smb", "snmp", "tftp", "x509", "bluetooth", "dhcp6", "llmnr" ]
     
 
 conf=Conf()
